Pycus
=====

Pycus adds Python virtual environments to Jupyter.

Usage
-----

See docs_.

.. _docs: https://pycus.readthedocs.io/en/latest/

Contributing
------------

* Observe the Code of Conduct in all interactions.
* In your first PR, add your name to the contributor list.


Contributors
------------

* Moshe Zadka <moshez@zadka.club>
